@@ -16,13 +16,14 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import ctypes
+import ctypes.util
 import logging
 import os
 import pickle
 import subprocess
 import sys
-import ctypes
-from ctypes import byref, c_float, c_int, pointer, util
+from ctypes import byref, c_float, c_int, pointer
 from pathlib import Path
 
 from gi.repository import GLib
@@ -60,7 +61,7 @@ if not sys.warnoptions:
 if sys.platform != "win32":
 	import fcntl
 
-n_version = "9.0.0" # Should also be bumped in pyproject.toml, extra/*.appdata.xml
+n_version = "9.1.0" # Should also be bumped in pyproject.toml, extra/*.appdata.xml
 t_version = "v" + n_version
 t_title = "Tauon"
 t_id = "tauonmb"
@@ -563,7 +564,7 @@ if __name__ == "__main__":
 		success = sdl3.SDL_ShowMessageBox(ctypes.byref(messageboxdata), ctypes.byref(buttonid))
 
 		if not success:
-			logging.error("SDL_ShowMessageBox failed:", sdl3.SDL_GetError().decode())
+			logging.error(f"SDL_ShowMessageBox failed: {sdl3.SDL_GetError().decode()}")
 		elif buttonid.value == BUTTON_ID_DISCORD:
 			open_discord()
 		elif buttonid.value == BUTTON_ID_GITHUB:
