@@ -35,7 +35,7 @@ from unidecode import unidecode
 
 
 def ovh(
-	artist: str, title: str, _user_agent: str = "unused here but it needs to exist in every lyrics function"
+	artist: str, title: str, user_agent: str = "unused here but it needs to exist in every lyrics function"
 ) -> tuple[str, str]:
 	"""Get lyrics from lyrics.ovh API"""
 	q = urllib.parse.quote(f"{artist}/{title}")
@@ -51,11 +51,11 @@ def genius(
 	artist: str,
 	title: str,
 	return_url: bool = False,
-	_user_agent: str = "unused here but it needs to exist in every lyrics function",
+	user_agent: str = "unused here but it needs to exist in every lyrics function",
 ) -> tuple[str, str] | str:
 	"""Scrape lyrics from genius.com"""
-	artist = artist.split("feat.")[0]
-	title = title.split("(feat.")[0]
+	artist = artist.split("feat.", maxsplit=1)[0].strip()
+	title = title.split("(feat.", maxsplit=1)[0].strip()
 	line = f"{artist}-{title}"
 	line = re.sub("[,._@!#%^*+:;'()]", "", line)
 	line = line.replace("]", "")
@@ -210,7 +210,7 @@ def get_lrclib_challenge(user_agent: str = "TauonMusicBox/Devel") -> tuple[str,
 	except requests.exceptions.ConnectionError:
 		return "", ""
 	except Exception:
-		logging.exception()
+		logging.exception("Unknown exception")
 		return "", ""
 	if r.status_code == HTTPStatus.OK:
 		p = r.json().get("prefix")
